clear all;close all;clc;


load test_signal

% Define input arguments

dt=3; % Sampling Time
fmin=0.002; % Lower Frequency
fmax=0.022; % Higher Frequency

Signal=test_signal(:,2);
Time=test_signal(:,1);

ind_nan=find(isnan(Signal));
Signal(ind_nan)=0;


% --------------------------------------------------------------------------
% Remove a 20-min running average
% --------------------------------------------------------------------------

Signal_detrend=smooth(Signal,round(1200/dt),'moving');

%--------------------------------------------------------------------------
% Plot Power Spectral Density
%--------------------------------------------------------------------------

Len=length(Signal_detrend);

[wavex,period,scale,coi] = WaveletPSD(Signal_detrend,dt,1,fmin,50,fmax,'MORLET',6);
power = (abs(wavex)).^2 ;        % compute wavelet power spectrum

frequency=1./period;

dF_wavelet = diff(1./period);
dF_wavelet = -1 * [ dF_wavelet,  dF_wavelet(end) ];

ind_sc=find(scale>=1/fmax & scale<=1/fmin);
frequency=frequency(ind_sc);
scale=scale(ind_sc);
dF_wavelet=dF_wavelet(ind_sc);

scale_avg = (scale')*(ones(1,Len));  % expand scale --> (J+1)x(N) array
power_F = power(ind_sc,:)./scale_avg./(2*dF_wavelet');   % [Eqn(24)]
power_F=power_F';

fourierFactor=4*pi/(6+sqrt(2+6^2));
dj = .25;
s0 = 2*dt;
sMAX = 3600; % maximum scale in seconds
j1 = round(log2(sMAX/s0))/dj;
Cdelta=0.776;
mother='MORLET';
power_total_F = 2*(dj*dt/Cdelta)*sum(power_F');   % [Eqn(24)]
power_total_F=power_total_F';

frequency=frequency*1000;

figure(1)
yyaxis left
imagesc(Time,frequency,log10(power_F'),[-4 3]);
colormap jet
ch=colorbar;
h=get(ch,'ylabel');
set(h,'String','Log_{10}(Power) [nT^{2}/Hz]','rot',90,'VerticalAlignment','Top');
title([datestr(round(Time(100)))]);
datetick('x','HH:MM');
ylabel('f (mHz)')
xlim([Time(1) Time(end)]);

yyaxis right
plot(Time,log10(power_total_F),'.k');
